Linux Sound subsystem development
 help / color / mirror / Atom feed
From: Peter Ujfalusi <peter.ujfalusi@linux.intel.com>
To: vkoul@kernel.org, perex@perex.cz, tiwai@suse.com,
	lgirdwood@gmail.com, broonie@kernel.org,
	srinivas.kandagatla@oss.qualcomm.com
Cc: linux-sound@vger.kernel.org, kai.vehmanen@linux.intel.com,
	yung-chuan.liao@linux.intel.com, pierre-louis.bossart@linux.dev,
	daniel.baluta@nxp.com
Subject: [PATCH v5 20/28] ASoC: SOF: ipc4-pcm: Handle COMPR DRAIN triggers as EOS pipeline state
Date: Wed,  7 Oct 2026 11:49:47 +0300	[thread overview]
Message-ID: <20261007084955.1256-21-peter.ujfalusi@linux.intel.com> (raw)
In-Reply-To: <20261007084955.1256-1-peter.ujfalusi@linux.intel.com>

The DRAIN trigger is received by a compr device when user space wrote all
the data to the buffer and it is waiting for the decoding to be completed.

Set the pipeline state to EOS in firmware so it can expect the stream to
be stopping anytime soon.

Signed-off-by: Peter Ujfalusi <peter.ujfalusi@linux.intel.com>
Reviewed-by: Liam Girdwood <liam.r.girdwood@intel.com>
---
 sound/soc/sof/ipc4-pcm.c | 19 +++++++++++++++----
 1 file changed, 15 insertions(+), 4 deletions(-)

diff --git a/sound/soc/sof/ipc4-pcm.c b/sound/soc/sof/ipc4-pcm.c
index c565e0e12949..f65c2a804a36 100644
--- a/sound/soc/sof/ipc4-pcm.c
+++ b/sound/soc/sof/ipc4-pcm.c
@@ -153,7 +153,8 @@ sof_ipc4_add_pipeline_to_trigger_list(struct snd_sof_dev *sdev, int state,
 	struct snd_sof_widget *pipe_widget = spipe->pipe_widget;
 	struct sof_ipc4_pipeline *pipeline = pipe_widget->private;
 
-	if (pipeline->skip_during_fe_trigger && state != SOF_IPC4_PIPE_RESET)
+	if (pipeline->skip_during_fe_trigger && state != SOF_IPC4_PIPE_RESET &&
+	    state != SOF_IPC4_PIPE_EOS)
 		return;
 
 	switch (state) {
@@ -173,7 +174,12 @@ sof_ipc4_add_pipeline_to_trigger_list(struct snd_sof_dev *sdev, int state,
 							  true);
 		break;
 	case SOF_IPC4_PIPE_PAUSED:
-		/* Pause the pipeline only when its started_count is 1 more than paused_count */
+	case SOF_IPC4_PIPE_EOS:
+		/*
+		 * Pause the pipeline only when its started_count is 1 more than
+		 * paused_count.
+		 * Same rule applies to EOS state.
+		 */
 		if (spipe->paused_count == (spipe->started_count - 1))
 			sof_ipc4_add_pipeline_by_priority(trigger_list, pipe_widget, pipe_priority,
 							  true);
@@ -492,8 +498,9 @@ static int sof_ipc4_trigger_pipelines(struct snd_soc_component *component,
 		goto free;
 	}
 
-	/* no need to pause before reset or before pause release */
-	if (state == SOF_IPC4_PIPE_RESET || cmd == SNDRV_PCM_TRIGGER_PAUSE_RELEASE)
+	/* no need to pause before reset, EOS or before pause release */
+	if (state == SOF_IPC4_PIPE_RESET || state == SOF_IPC4_PIPE_EOS ||
+	    cmd == SNDRV_PCM_TRIGGER_PAUSE_RELEASE)
 		goto skip_pause_transition;
 
 	/*
@@ -591,6 +598,10 @@ static int sof_ipc4_pcm_trigger(struct snd_soc_component *component,
 	case SNDRV_PCM_TRIGGER_STOP:
 		state = SOF_IPC4_PIPE_PAUSED;
 		break;
+	case SND_COMPR_TRIGGER_DRAIN:
+	case SND_COMPR_TRIGGER_PARTIAL_DRAIN:
+		state = SOF_IPC4_PIPE_EOS;
+		break;
 	default:
 		dev_err(component->dev, "%s: unhandled trigger cmd %d\n", __func__, cmd);
 		return -EINVAL;
-- 
2.56.0


  parent reply	other threads:[~2026-10-07  8:50 UTC|newest]

Thread overview: 30+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-10-07  8:49 [PATCH v5 00/28] ALSA compress / ASoC compress / SOF: Compressed audio support with IPC4 Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 01/28] ALSA: compress: pin card module while stream is open Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 02/28] ALSA: compress: register the open file with the card Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 03/28] ALSA: compress: stop active streams on disconnect Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 04/28] ALSA: compress: Set the draining state before the drain trigger Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 05/28] ASoC: soc-compress: Provide a runtime for the compressed FE substream Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 06/28] ASoC: soc-compress: Implement trigger FE-BE sequencing as with normal PCMs Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 07/28] ASoC: soc-compress: Stop running dpcm on free Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 08/28] ASoC: SOF: compress: Move the IPC agnostic helpers to sof-audio.c Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 09/28] ASoC: SOF: compress: Rename compress ops with ipc3 prefix Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 10/28] ASoC: SOF: sof-audio: Fix the pipeline_list population Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 11/28] ASoC: SOF: ipc4-pcm: Serialize the PCM free with the pipeline triggers Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 12/28] ASoC: SOF: sof-audio: do not dereference swidget->spipe unconditionally on free Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 13/28] ASoC: SOF: sof-audio: Expose a couple of functions Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 14/28] ASoC: SOF: pcm: Modify the signature of a couple of PCM IPC ops Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 15/28] ASoC: SOF: intel: hda-stream: Clear the current position when releasing stream Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 16/28] ASoC: SOF: ipc4: Add definition of module data in init_ext object type Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 17/28] ASoC: SOF: ipc4-topology: Support init_ext_module_data for process modules Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 18/28] ASoC: SOF: ipc4-pcm: Make the timestamp info usable outside of ipc4-pcm.c Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 19/28] ASoC: SOF: ipc4/ipc4-loader: Add SOF_INFO and CODEC_INFO to fw_config_params Peter Ujfalusi
2026-10-07  8:49 ` Peter Ujfalusi [this message]
2026-10-07  8:49 ` [PATCH v5 21/28] ASoC: SOF: ipc4-topology: Set FAST_MODE for host copier in compr mode Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 22/28] ASoC: SOF: ops: Add new platform-specific ops for compress Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 23/28] ASoC: SOF: Check that the audio buffer fits into the page table Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 24/28] ASoC: SOF: Add support for IPC4 compressed Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 25/28] ASoC: SOF: ipc4: Handle compressed drain done notification from firmware Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 26/28] ASoC: SOF: Intel: Kconfig: Remove redundant IPC version selects Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 27/28] ASoC: SOF: Intel: Kconfig: Select compress support for TGL+ platforms Peter Ujfalusi
2026-10-07  8:49 ` [PATCH v5 28/28] ASoC: SOF: topology: Add support for decoder and encoder widgets Peter Ujfalusi
2026-10-07 11:17 ` [PATCH v5 00/28] ALSA compress / ASoC compress / SOF: Compressed audio support with IPC4 Mark Brown

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20261007084955.1256-21-peter.ujfalusi@linux.intel.com \
    --to=peter.ujfalusi@linux.intel.com \
    --cc=broonie@kernel.org \
    --cc=daniel.baluta@nxp.com \
    --cc=kai.vehmanen@linux.intel.com \
    --cc=lgirdwood@gmail.com \
    --cc=linux-sound@vger.kernel.org \
    --cc=perex@perex.cz \
    --cc=pierre-louis.bossart@linux.dev \
    --cc=srinivas.kandagatla@oss.qualcomm.com \
    --cc=tiwai@suse.com \
    --cc=vkoul@kernel.org \
    --cc=yung-chuan.liao@linux.intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox